class User < ActiveRecord::Base
  include RepositoriesProxy

  # Include default devise modules. Others available are:
  # :confirmable, :lockable, :timeoutable and :omniauthable
  devise :database_authenticatable, :registerable,
         :recoverable, :rememberable, :trackable, :validatable

  has_and_belongs_to_many :roles
  has_and_belongs_to_many :institutions
  has_many :bookmarks
  has_many :collections

  has_many :learning_objects, as: :publisher

  has_many :views
  has_many :downloads
  has_many :likes
  has_many :shares

  has_many :follows
  has_many :follows, as: :followable

  after_create :default_role

  has_attached_file :avatar, styles: {medium: "300x300>", thumb: "60x60>"}, default_url: lambda { |image| ActionController::Base.helpers.asset_path('user-anon.png') }
  validates_attachment_content_type :avatar, content_type: /\Aimage\/.*\Z/

  def collections
    #public_collections = collection_repository.all(Collections::UserPublicContext.new(self))
   # private_collections = collection_repository.all(Collections::UserPrivateContext.new(self))
    #@collections = public_collections + private_collections
  end

  def institutions
    institution_repository.associated_with self
  end

  def bookmarks
    collection_repository.bookmarks self
  end

  def learning_objects
    learning_object_repository.all self
  end

  def is_admin?
    roles.each do |role|
      return true if role.name == "admin"
    end
    false
  end

  private

  def default_role
  #  roles << role_repository.find_by_name("teacher")
  end

end
