class View < ActiveRecord::Base
  belongs_to :viewable, polymorphic: true, counter_cache: true
  belongs_to :user

  scope :user_object, ->(user, object) { where(user: user, viewable: object) }
  scope :user_object_last, ->(user, object) { user_object(user, object).order('created_at DESC').limit(1).first }

  before_create :current_time_greater_than_last

  private

  def current_time_greater_than_last
    last_view = View.user_object_last(user, viewable)

    unless last_view.blank?
      return false if Time.now < (last_view.created_at + 1.days)
    end

    true
  end
end
